@@ -1543,6 +1543,11 @@ public class BookStore {
         }
     }
 
+    @POST
+    @Path("/no-content")
+    public void noContent() {
+    }
+
     @POST
     @Path("/books/customstatus")
     @Produces("application/xml")
